@@ -16,7 +16,7 @@ from dallinger.config import get_config
 
 def get_base_url():
     config = get_config()
-    host = config.get("host")
+    host = os.getenv("HOST", config.get("host"))
     if "herokuapp.com" in host:
         if host.startswith("https://"):
             base_url = host
